@@ -7,11 +7,7 @@ import os
 from pysentiment.utils import Tokenizer
 
 
-if os.path.exists('/usr/local/pysentiment.static'):
-    # if data is installed
-    STATIC_PATH = '/usr/local/pysentiment.static'
-else:
-    STATIC_PATH = os.path.dirname(__file__)+'/../static'
+STATIC_PATH = os.path.dirname(__file__)+'/static'
 
 
 class BaseDict(object):
